# SimpleConnectorStatus

The status for a site (ie. Connector). This provides info to User Resources if the site is not accessible, thereby the Resource is not accessible. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**connector_id** | **str** | Unique identifier | 
**status** | **str** | The status can have the following values: - A &#x60;good&#x60; status means that no action is neccessary - A &#x60;down&#x60; status indicates that either the AdminStatus for the entity   has is set to &#x60;down&#x60;, or there is a entity accessibility problem   that should be dealt with as soon as possible. - A &#x60;degraded&#x60; status indicates that the entity is operational but running   in non-redundant mode. Note that this alarm would only be valid for   a entity that supports redundancy. - A &#x60;testing&#x60; status indicates the entity the entities AdminStatus has been   placed into &#x60;testing&#x60;. - A &#x60;deleted&#x60; status indicates the entity has been deleted.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


